@@ -10,19 +10,34 @@ from bs4 import BeautifulSoup
 from dwca.read import DwCAReader, GBIFResultsReader
 from dwca.rows import CoreRow, ExtensionRow
 from dwca.darwincore.utils import qualname as qn
-from dwca.exceptions import RowNotFound
+from dwca.exceptions import RowNotFound, InvalidArchive
 from dwca.descriptors import ArchiveDescriptor
 
 from .helpers import (GBIF_RESULTS_PATH, BASIC_ARCHIVE_PATH, EXTENSION_ARCHIVE_PATH,
                       MULTIEXTENSIONS_ARCHIVE_PATH, NOHEADERS1_PATH, NOHEADERS2_PATH,
                       IDS_ARCHIVE_PATH, DEFAULT_VAL_PATH, UTF8EOL_ARCHIVE_PATH,
-                      DIRECTORY_ARCHIVE_PATH, DEFAULT_META_VALUES)
+                      DIRECTORY_ARCHIVE_PATH, DEFAULT_META_VALUES, INVALID_LACKS_METADATA)
 
 
 class TestDwCAReader(unittest.TestCase):
     # TODO: Move row-oriented tests to another test class
     """Unit tests for DwCAReader class."""
 
+    def test_exception_invalid_archives(self):
+        """Ensure an InvalidArchive exception is raised when the archive is invalid."""
+
+        # Sometimes, the archive metafile references a metadata file that's not present in the
+        # archive. See for example http://dev.gbif.org/issues/browse/PF-2125
+        with self.assertRaises(InvalidArchive) as cm:
+            a = DwCAReader(INVALID_LACKS_METADATA)
+            a.close()
+
+        the_exception = cm.exception
+        expected_message = "eml.xml is referenced in the archive descriptor but missing."
+        self.assertEqual(the_exception.message, expected_message)
+
+        # TODO: Once implemented, test here other cases of InvalidArchive exceptions.
+
     def test_default_values_metafile(self):
         """Ensure default values are used when optional attributes are absent in metafile.
 
@@ -95,7 +110,7 @@ class TestDwCAReader(unittest.TestCase):
         """Test the absolute_temporary_path() method."""
         with DwCAReader(BASIC_ARCHIVE_PATH) as dwca:
             path_to_occ = dwca.absolute_temporary_path('occurrence.txt')
-            
+
             # Is it absolute ?
             self.assertTrue(os.path.isabs(path_to_occ))
             # Does file exists ?
@@ -108,7 +123,7 @@ class TestDwCAReader(unittest.TestCase):
         with DwCAReader(DIRECTORY_ARCHIVE_PATH) as dwca:
             # Also check if the archive is a directory
             path_to_occ = dwca.absolute_temporary_path('occurrence.txt')
-            
+
             # Is it absolute ?
             self.assertTrue(os.path.isabs(path_to_occ))
             # Does file exists ?
